@@ -17,7 +17,7 @@ cmake ${CMAKE_ARGS} -GNinja \
     -DF2C_EXTERNAL_ARITH_HEADER=$F2C_EXTERNAL_ARITH_HEADER \
     -DIGRAPH_USE_INTERNAL_BLAS=0 \
     -DIGRAPH_USE_INTERNAL_LAPACK=0 \
-    -DIGRAPH_USE_INTERNAL_ARPACK=$INTERNAL_ARPACK \
+    -DIGRAPH_USE_INTERNAL_ARPACK=0 \
     -DIGRAPH_USE_INTERNAL_GLPK=0 \
     -DIGRAPH_USE_INTERNAL_CXSPARSE=0 \
     -DIGRAPH_USE_INTERNAL_GMP=0 \
